#
# spec file for package perl-Mail-IMAPClient
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mail-IMAPClient
Name:           perl-Mail-IMAPClient
Version:        3.43
Release:        1.17
Summary:        An IMAP Client API
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PL/PLOBBES/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Parse::RecDescent) >= 1.94
Requires:       perl(Parse::RecDescent) >= 1.94
%{perl_requires}

%description
This module provides methods implementing the IMAP protocol to support
interacting with IMAP message stores.

The module is used by constructing or instantiating a new IMAPClient object
via the new constructor method. Once the object has been instantiated, the
connect method is either implicitly or explicitly called. At that point
methods are available that implement the IMAP client commands as specified
in *RFC3501*. When processing is complete, the logout object method should
be called.

This documentation is not meant to be a replacement for RFC3501 nor any
other IMAP related RFCs.

Note that this documentation uses the term _folder_ in place of RFC3501's
use of _mailbox_. This documentation reserves the use of the term _mailbox_
to refer to the set of folders owned by a specific IMAP id.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
for f in examples/*.pl
do
   sed -i 's|^#!/usr/local/bin/perl|%{__perl}|' ${f}
done
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples prepare_dist README test_template.txt

%changelog
* Fri Feb 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.43
  see /usr/share/doc/packages/perl-Mail-IMAPClient/Changes
  version 3.43: Tue Feb 16 16:53:26 UTC 2021
  - admin: update copyright, move from rt.cpan.org (retired) to github
  - rt.cpan.org#132720: compress: Readmethod: avoid false-positive EOF
  [Eric Wong]
  - rt.cpan.org#129920: Parsing headers fails under special condition
  [Jens Berthold]
  - rt.cpan.org#132654: avoid cyclic reference on ->compress
  [Eric Wong]
  - rt.cpan.org#132380: append_string can fail to match APPENDUID in response
  [Radomír Polách]
  - rt.cpan.org#133496: allow for undocumented BODYSTRUCTURE extensions
  [Rhesa Rozendaal]
* Sat Nov 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Convert changes file to proper UTF-8 format: new
  version of RPM are getting strict in interpreting files.
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.42
  see /usr/share/doc/packages/perl-Mail-IMAPClient/Changes
  version 3.42: Sun Feb 24 00:43:29 UTC 2019
  - rt.cpan.org#12859: has_capability() changes in 3.41 broke imap4rev1()
  [Gilles Lamiral and Gábor Leszlauer]
  - updated http:// to https:// URLs for referenced resources
  - updated copyright for 2019
* Thu Feb 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.41
  see /usr/share/doc/packages/perl-Mail-IMAPClient/Changes
  version 3.41: Thu Feb 21 01:47:42 UTC 2019
  - rt.cpan.org#128220: unseen(), messages() and related POD cleanup
  [Dan Jacobson]
  - rt.cpan.org#128264: parse_message() minor code/POD cleanup
  [Dan Jacobson]
  - rt.cpan.org#128215: verb missing in messages() POD
  [Gilles Lamiral and Dan Jacobson]
  - rt.cpan.org#127271: simplify capability handling via has_capability enhancements
  +* has_capability() success returns(true) with server response data, not always '1'
  + enhanced t/capability.t test cases
  + updated POD for capability() and has_capability()
  [Gilles Lamiral and Mark Overmeer]
  - rt.cpan.org#122373: use of IO::Socket::IP led to connect(empty args) regression
  [Gilles Lamiral]
  - rt.cpan.org#128127: fix minor POD typo for search()
  [Gregor Herrmann]
  - folders()/subscribed() remove mailboxes with \Noselect attribute
  [Ashley Willis]
  - fetch_hash() remove quotes around header names (seen w/outlook.com)
  [Ashley Willis]
  - use first over grep for minor efficiency gains
  - other minor POD cleanup
* Sat Jan 19 2019 Luigi Baldoni <aloisio@gmx.com>
- Fixed shebangs in example scripts
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 3.40
  see /usr/share/doc/packages/perl-Mail-IMAPClient/Changes
  version 3.40: Thu Dec  6 01:44:16 UTC 2018
  - rt.cpan.org#122373 support IPv6 by using IO::Socket::IP over IO::Socket::INET
  [Gilles Lamiral and Mark Overmeer]
  - rt.cpan.org#127103 flags() undef value as an ARRAY reference on a bogus message
  [Gilles Lamiral]
  - rt.cpan.org#124523 update examples/populate_mailbox.pl timegm usage
  [Bernhard M. W.]
  - t/capability.t: added first set of tests
  - t/quota.t: minor fix when tests skipped
  version 3.39: Fri Feb  3 00:43:00 UTC 2017
  - rt.cpan.org#115726: uninitialized value via fetch_hash
  [Malte Stretz]
  - rt.cpan.org#119523: better error reporting on failed TLS connections
  [Matthew Horsfall]
  - rt.cpan.org#114904: document noop()
  [Glenn Golden]
  - rt.cpan.org#97718: (redux) never retry DONE
  [Laurence Darby]
  - _imap_command() new doretry => 0|1 option to suppress/allow retry
  - updated copyright for 2017
  version 3.38: Tue Feb  9 02:48:21 UTC 2016
  - rt.cpan.org#107592: redact credentials via debug if !Showcredentials
  [Gilles Lamiral]
  - rt.cpan.org#110273: failure to quote password values
  (regression introduced in 3.36 via fix for rt.cpan.org#100601)
  [Gilles Lamiral]
  - rt.cpan.org#107593: allow getquota("")
  - *Quote() now returns qq("") for defined but empty values
  - rt.cpan.org#107011: fix folders_hash() docs and usage in is_parent()
  [Gilles Lamiral]
  - rt.cpan.org#106500: split UID EXPUNGE with a large sequence set
  - added t/quota.t and t/lib/MyTest.pm for testing
  - updated copyright for 2016
* Sun Mar 13 2016 chris@computersalat.de
- fix deps
  * perl(version) >= 0.77
  * perl(IO::Socket::INET) >= 1.26
* Sun Aug 23 2015 coolo@suse.com
- updated to 3.37
  see /usr/share/doc/packages/perl-Mail-IMAPClient/Changes
  version 3.37: Fri Aug 14 11:04:53 EDT 2015
  - regex fix in rt.cpan.org#96575 required Perl 5.10
  updated regex to be backwards compatible with Perl 5.8
  [Paul Howarth]
  version 3.36: Fri Aug 14 01:40:50 UTC 2015
  - rt.cpan.org#96575: parsing fixes for fetch_hash and bodystructure
  + better handling of data containing escaped characters
  [Ken Neighbors]
  - rt.cpan.org#97718: hang waiting for tag if DONE sent outside of IDLE
  [Laurence Darby]
  - rt.cpan.org#100683: failed literal commands hang waiting for '+'
  [Matthias Pitzl]
  - rt.cpan.org#100601: login() fails if username requires use of literals
  [Andy Lyttle]
  - *rt.cpan.org#103823: is_parent() should return undef on \NoInferiors
  [Gilles Lamiral]
  - rt.cpan.org#105456: fetch_hash fails if sequence number contains '*'
  + *no longer removing unrequested data (except UID) in returned hashes
  [Gilles Lamiral]
  - rt.cpan.org#91912: selectable broke in 3.29 due to BS/^H around \NoSelect
  [Justin Vallon, Gilles Lamiral]
  - some documentation, test cleanup and new tests
* Tue Apr 14 2015 coolo@suse.com
- updated to 3.35
  see /usr/share/doc/packages/perl-Mail-IMAPClient/Changes
  version 3.35: Fri, Nov 22, 2013  2:18:41 PM
  - *use Quote() over Massage() to avoid stripping double quotes from arg
  + removed constant NonFolderArg
  + may deprecate Massage() in a future release
  - _list_or_lsub failed to handle folder names with double quotes
  + cleanup Escaped_results()
  + new methods: Escaped_history() _escaped_trans_data()
  + removed method: _list_response_preprocess()
  [Gilles Lamiral, Victor Lé]
  - rt.cpan.org#90315: getacl on a folder returned as literal failed
  + _read_line could remove extra space when literal data was received
  [Carl Karcher]
  - rt.cpan.org#89040: typo fixes
  [David Steinbrunner]
  version 3.34: Fri, Sep 27, 2013 12:50:17 AM
  - make Makefile.PL use non-interactive and document test.txt usage
  - new attribute: Socketargs => [ (IO::Socket::.. args) ]
  + cleanup connect() to more flexible with IO::Socket::* args
  - untagged server data during send literal may cause client to hang
  [Arthur Wolfe, Josh Hillman]
  + _send_line() needs '+' only to know it is OK to send LITERAL data
  + created _response_code_sub() to simplify _get_response()
  - remove internal "Folders" cache
  - Allow for RFC 6154 "IMAP LIST Extension for Special-Use Mailboxes"
  [Mathias Reitinger]
  + new method: folders_hash()
  + deprecate: xlist_folders(), xlist()
  version 3.33: Tue, May 14, 2013 10:12:43 AM
  - more cleanup on use of $@ and $!
  - cleanup get_bodystructure / get_envelope
  - allow Ssl arg as an arrayref to pass args to IO::Socket::SSL
  [Ramana V Mokkapati]
  - no need to Massage() the folder name in uidnext()
  - rt.cpan.org#84028: get_envelope() fails when subject ends w/backslash
  [Andy Lyttle]
  - rt.cpan.org#79476: move()/copy() with sequence causes numeric warning
  [Oleg G]
  - *move()/copy() no longer sort message(s) provided by caller
* Fri Jan 25 2013 chris@computersalat.de
- update to 3.32
  * document RFC2087 quota related calls
    [Mathias Reitinger] documentation request
  * rt.cpan.org#78474: idle/idle_data documentation error
    [Dima Kogan]
  * Quote()/Massage() now uses literals for non ascii data
    [Mathias Reitinger] reported issues with utf8 data in password
  * use Quote()/Massage() consistently now in:
    login() proxyauth() deleteacl() setacl() listrights() rename()
  * documented deleteacl() and other minor pod cleanup
  * ran Mail::IMAPClient::BodyStructure through perltidy
  * update year in README/pod to 2012
  * rt.cpan.org#74733: Fails with Parse::RecDescent >= 1.966_002
    rt.cpan.org#74593: Recent changes break Module::ExtractUse and ...
    [ANDK, TEAM, SREZIC, NBEBOUT at CPAN and nine from detonation]
  - Makefile.PL avoid buggy Parse::RecDescent 1.966_002 until 1.967_009
  * rt.cpan.org#76989: Mail::IMAPClient::BodyStructure usage/docs
    [Pierluigi Frullani]
  - fix incorrect documentation on new()
  - lots of doc verbiage updates
- fix deps
  * Parse-RecDescent HACK needs perl(persion) > 0.74
  * add missing Recommends
* Mon Nov 28 2011 aj@suse.de
- update to 3.29
  * bugfixes, see Changes.
- Fix examples to use proper perl path.
* Tue Apr 26 2011 coolo@opensuse.org
- updated to 3.28
  * tons of bug fixes, see Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Apr  3 2010 chris@computersalat.de
- update to 3.23
  - new beta idle_data() method to retrieve untagged messages during idle
    similar to method suggested by Daniel Richard G
  - added/updated documentation for idle, idle_data, and done
  - rt.cpan.org#53998: fix NTLM auth: call ntlm with challenge string
    [Dragoslav Mlakar]
  - report the return value from select/_read_more on errors
  - logout() again returns the success/failure of the LOGOUT command
  - set/return error when $response->() returns undef in authenticate()
  - new internal method _load_module() centralizing some 'require' calls
  - localize use $@ in several places to avoid stomping on global val
  - refactor code calling _read_more() to centralize error handling
- version 3.22: Thu Jan 21 15:25:54 EST 2010
  - rt.cpan.org#52313: Getting read errors if Fast_io is set to 1
    [Jukka Huhta]
  - updated Maxttemperrors docs related to EAGAIN handling
  - new starttls() method and Starttls attribute to support STARTTLS
  - update parse_headers to try harder to find UID in fetch response
- for older changes please see Changes file
- spec mods
  o added HEADER
  o sort TAGS
  o fixed deps
  o updated description
  o macros
- added perl-macros
- moved changelog to changes file
* Fri Oct 31 2008 rbos@opensuse.org
- Fixed rpmlint errors
